.. bran documentation master file, created by
   sphinx-quickstart on Tue Oct 25 10:28:07 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Documentation of bran |release|
============================================

Swagger/OpenAPI 2.0 Parser for Python

.. include:: ../../README.rst

.. toctree::
   :hidden:

API/Modules
===========

.. autosummary::
   :toctree: api

   bran
